@@ -1,4 +1,4 @@
-# $Id: as3935.py 1329 2015-06-18 15:20:40Z mwall $
+# $Id: as3935.py 1346 2015-07-31 11:25:27Z mwall $
 # Copyright 2015 Matthew Wall
 
 """
@@ -59,7 +59,11 @@ from datetime import datetime
 from weewx.wxengine import StdService
 from weeutil.weeutil import to_bool
 
-VERSION = "0.2"
+VERSION = "0.4"
+
+if weewx.__version__ < "3.2":
+    raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
+                                   weewx.__version__)
 
 schema = [('dateTime', 'INTEGER NOT NULL PRIMARY KEY'),
           ('usUnits', 'INTEGER NOT NULL'),
@@ -93,7 +97,7 @@ class AS3935(StdService):
         indoors = to_bool(svc_dict.get('indoors', True))
         noise_floor = int(svc_dict.get('noise_floor', 0))
         calib = int(svc_dict.get('calibration', 0x6))
-        pin = int(svc_dict.get('pin', 17))
+        self.pin = int(svc_dict.get('pin', 17))
         self.binding = svc_dict.get('data_binding', None)
 
         self.data = []
@@ -112,19 +116,33 @@ class AS3935(StdService):
                     raise Exception('as3935: schema mismatch: %s != %s' %
                                     (dbcol, memcol))
 
-        # configure the gpio and sensor
-        GPIO.setmode(GPIO.BCM)
-        GPIO.setup(pin, GPIO.IN)
+        # configure the sensor
         self.sensor = RPi_AS3935(address=addr, bus=bus)
         self.sensor.set_indoors(indoors)
         self.sensor.set_noise_floor(noise_floor)
         self.sensor.calibrate(tun_cap=calib)
 
+        # configure the gpio
+        GPIO.setmode(GPIO.BCM)
+        GPIO.setup(self.pin, GPIO.IN)
+
         # add a gpio callback for the lightning strikes
-        GPIO.add_event_detect(pin, GPIO.RISING, callback=self.handle_interrupt)
+        try:
+            # be sure nothing is registered already...
+            GPIO.remove_event_detect(self.pin)
+        except:
+            pass
+        # ... then add our handler
+        GPIO.add_event_detect(self.pin, GPIO.RISING,
+                              callback=self.handle_interrupt)
+
         # on each new archive record, read then clear data since last record
         self.bind(weewx.NEW_ARCHIVE_RECORD, self.read_data)
-   
+
+    def shutDown(self):
+        GPIO.remove_event_detect(self.pin)
+        GPIO.cleanup()
+
     def read_data(self, event):
         avg = None
         count = len(self.data)
@@ -133,9 +151,14 @@ class AS3935(StdService):
             for x in self.data:
                 avg += x[1]
             avg /= count
-        self.data = []
-        event.record['lightning_strikes'] = count
+        # if the record is not metric, convert from kilometers to miles
+        if event.record['usUnits'] == weewx.US:
+            avg = weewx.units.convert((avg, 'km', 'group_distance'), 'mile')[0]
+        # save the count and average
         event.record['avg_distance'] = avg
+        event.record['lightning_strikes'] = count
+        # clear the count and average
+        self.data = []
 
     def save_data(self, strike_ts, distance):
         if self.binding is None:
