@@ -1,4 +1,4 @@
-# $Id: install.py 1328 2015-06-18 13:56:19Z mwall $
+# $Id: install.py 1346 2015-07-31 11:25:27Z mwall $
 # installer for as3935 lightning detection on raspberry pi
 # Copyright 2015 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class AS3935Installer(ExtensionInstaller):
     def __init__(self):
         super(AS3935Installer, self).__init__(
-            version="0.2",
+            version="0.4",
             name='as3935',
             description='Capture lightning data from AS3935 hardware',
             author="Matthew Wall",
@@ -19,6 +19,8 @@ class AS3935Installer(ExtensionInstaller):
             config={
                 'AS3935': {
                     'address': '3',
-                    'bus': '1'}},
+                    'bus': '1',
+                    'pin': '17',
+                    'calibration': '6'}},
             files=[('bin/user', ['bin/user/as3935.py'])]
             )
